aboutsummaryrefslogtreecommitdiff
path: root/backends/platform
diff options
context:
space:
mode:
Diffstat (limited to 'backends/platform')
-rwxr-xr-xbackends/platform/bada/system.cpp5
1 files changed, 3 insertions, 2 deletions
diff --git a/backends/platform/bada/system.cpp b/backends/platform/bada/system.cpp
index 9b137d059a..f3f3083e5a 100755
--- a/backends/platform/bada/system.cpp
+++ b/backends/platform/bada/system.cpp
@@ -289,8 +289,9 @@ void BadaSystem::initBackend() {
// use the mobile device theme
ConfMan.set("gui_theme", "/Res/scummmobile");
- // allow virtual keypad pack to be found
- ConfMan.set("vkeybdpath", "/Res/vkeybd_default");
+ // allow bada virtual keypad pack to be found
+ ConfMan.set("vkeybdpath", "/Res/vkeybd_bada");
+ ConfMan.set("vkeybd_pack_name", "vkeybd_bada");
// set default save path to writable area
if (!ConfMan.hasKey("savepath")) {